@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2015-06-08 - v1.002
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.046.
+
+=item *
+
 2013-12-09 - v1.001
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.038.
@@ -181,8 +187,8 @@ EVRA EVRC EVRR EVRS EVTA EVVA EYAL EYBI EYKA EYKG EYKL EYKR EYKS EYKT
 EYMA EYMM EYNA EYND EYPA EYPI EYPN EYPP EYPR EYRK EYSA EYSE EYSI EYTL
 EYVA EYVC EYVI EYVK EYVL EYVN EYZA FAAB FAAN FABL FABM FABY FACL FACT
 FACV FADA FADN FAEL FAEO FAFF FAFR FAGB FAGE FAGG FAGM FAGR FAHS FAIR
-FAJS FAKM FALA FALE FALT FALW FALY FAMB FAME FAMG FAMM FAMO FANC FANS
-FAOB FAOH FAPB FAPE FAPH FAPI FAPJ FAPM FAPR FAQT FARB FASB FATC FATN
+FAKM FALA FALE FALT FALW FALY FAMB FAME FAMG FAMM FAMO FANC FANS
+FAOB FAOH FAOR FAPB FAPE FAPH FAPI FAPJ FAPM FAPR FAQT FARB FASB FATC FATN
 FATZ FAUP FAUT FAVB FAVR FAVY FAWB FAWK FAWM FAWW FBCO FBFT FBGM FBGR
 FBGZ FBHQ FBJW FBKE FBKG FBKR FBKY FBLT FBMG FBMM FBMN FBMS FBNN FBNT
 FBOK FBOR FBPA FBPY FBRK FBSD FBSK FBSN FBSP FBSV FBSW FBTE FBTL FBTP
