@@ -29,8 +29,23 @@ Source: L<http://www.learntarot.com/>
 
 Abigail
 
-Introduced in Acme-MetaSyntactic-Themes version 1.005,
-published on June 11, 2012.
+=head1 CHANGES
+
+=over 4
+
+=item *
+
+2012-06-11 - v1.000
+
+Introduced in Acme-MetaSyntactic-Themes version 1.005.
+
+=item,*
+
+2005-11-01
+
+Submitted by Abigail.
+
+=back
 
 =head1 SEE ALSO
 
